moStorages = {};
source(MultiOverlayV3.modDir.."scripte/module/storages/moStoragesConfig.lua");

function moStorages:update(dt)
	if moModule.active.storages.isRunning then
		if moStorages.values.updateTimer > 0 then
			if MultiOverlayV3.timers["updateStorages"] ~= nil then return;end; 
			moSetGetExtras:addTimer( {delay=moStorages.values.updateTimer, name="updateStorages", repeatable=1, ms=moStorages.values.msec, action=moStorages.loadStorages} )
		else
			moStorages:loadStorages();
		end;
	end;
end;

function moStorages:loadStorages()	
	moStorages:loadTotalStorages();	
end;

function moStorages:loadTotalStorages()	
	local playerFarmId = g_currentMission.player.farmId;
	moStorages.values.storages = {}; --new 
	if moModule.storages ~= nil and #moModule.storages > 0 then
		local deleteObject = {};
		for index=1, #moModule.storages do
			if moModule.storages[index] ~= nil then
				local isObject = moModule:isObject(moModule.storages[index].object);
				if isObject then
					local storage = moModule.storages[index].object;
					if storage.ownerFarmId == 0 or storage.ownerFarmId == playerFarmId and not moModule.storages[index].extension then
						local storageName = moModule.storages[index].xmlName;
						if moStorages.values.storages[storageName] == nil then moStorages.values.storages[storageName] = {};end;
						moStorages.values.storages[storageName][#moStorages.values.storages[storageName]+1] = {general={},output={},input={}};
						
						local lineTableGeneral = moStorages.values.storages[storageName][#moStorages.values.storages[storageName]].general;
						lineTableGeneral[#lineTableGeneral+1] = {};
						local isLineTableGeneral = lineTableGeneral[#lineTableGeneral];						
						isLineTableGeneral.object = storage;
						isLineTableGeneral.ownerFarmId = storage.ownerFarmId or 0;
						isLineTableGeneral.objectName = moModule.storages[index].name;
						if moModule.storages[index].mohDisplayName ~= nil then isLineTableGeneral.objectName = moModule.storages[index].mohDisplayName;end;
						isLineTableGeneral.xmlName = storageName;
						isLineTableGeneral.capacityTotal = 0;
						isLineTableGeneral.capacity = 0;
						isLineTableGeneral.percentageCapacityTotal = 0;
						isLineTableGeneral.extension = moModule.storages[index].extension;
						isLineTableGeneral.foreignSilo = storage.foreignSilo;
						isLineTableGeneral.productivity = 0; 
						isLineTableGeneral.productivityName = moLanguageXml:getTxt("productivity1", nil, "Usage");
						isLineTableGeneral.productivityColor = 1;
						if storage.viewOutput == nil then storage.viewOutput = false;end;
						if storage.viewInput == nil then storage.viewInput = false;end;
						--isLineTableGeneral.viewOutput = Utils.getNoNil(storage.viewOutput, false);
						--isLineTableGeneral.viewInput = Utils.getNoNil(storage.viewInput, false);
						
						local totalFillLevel = 0;
						local totalCapacity = 0;
						local lineTableOutput = moStorages.values.storages[storageName][#moStorages.values.storages[storageName]].output;
						local lineTableInput = moStorages.values.storages[storageName][#moStorages.values.storages[storageName]].input;
						function setOutput(fillTypeIndex, fillLevel, capacity)
							lineTableOutput[#lineTableOutput+1] = {};						
							local isLineTableOutput = lineTableOutput[#lineTableOutput];
							local fillType = moFillTypes.values.fillTypes[fillTypeIndex];
							if fillType ~= nil then
								isLineTableOutput.fillTypeName = fillType.name;
							else
								isLineTableOutput.fillTypeName = moLanguageXml:getTxt("unknown", nil, "Unknown");
							end;
							isLineTableOutput.fillLevel = g_i18n:formatNumber(Utils.getNoNil(fillLevel, 0));
							isLineTableOutput.capacity = g_i18n:formatNumber(Utils.getNoNil(capacity, 0));
							isLineTableOutput.percentageCapacity = math.floor(100 * (fillLevel/capacity));
							totalFillLevel = totalFillLevel+Utils.getNoNil(fillLevel, 0);
							totalCapacity = totalCapacity+Utils.getNoNil(capacity, 0);
						end;
						function setInput(fillTypeIndex, fillLevel, capacity)
							lineTableInput[#lineTableInput+1] = {};						
							local isLineTableInput = lineTableInput[#lineTableInput];
							local fillType = moFillTypes.values.fillTypes[fillTypeIndex];
							if fillType ~= nil then
								isLineTableInput.fillTypeName = fillType.name;
							else
								isLineTableInput.fillTypeName = moLanguageXml:getTxt("unknown", nil, "Unknown");
							end;
							isLineTableInput.fillLevel = g_i18n:formatNumber(Utils.getNoNil(fillLevel, 0));
							isLineTableInput.capacity = g_i18n:formatNumber(Utils.getNoNil(capacity, 0));
							isLineTableInput.percentageCapacity = math.floor(100 * (fillLevel/capacity));
							totalFillLevel = totalFillLevel+Utils.getNoNil(fillLevel, 0);
							totalCapacity = totalCapacity+Utils.getNoNil(capacity, 0);
						end;
						if storage.storages ~= nil and #storage.storages > 0 then
							for s=1, #storage.storages do
								for fillTypeIndex,isAccepted in pairs(storage.storages[s].fillTypes) do
									if isAccepted then
										local fillLevel = Utils.getNoNil(storage.storages[s]:getFillLevel(fillTypeIndex), 0);
										local capacity = Utils.getNoNil(storage.storages[s]:getCapacity(fillTypeIndex), 0);
										if capacity ~= 0 and isLineTableGeneral.capacity == 0 then isLineTableGeneral.capacity = g_i18n:formatNumber(Utils.getNoNil(capacity, 0));end;
										if moFillTypes.values.fillTypes[fillTypeIndex] ~= nil then
											if fillLevel > 0.01 then setOutput(fillTypeIndex, fillLevel, capacity);end;
											setInput(fillTypeIndex, fillLevel, capacity);
										end;
									end;
								end;
							end;
						end;
						isLineTableGeneral.percentageCapacityTotal = math.floor(100 * (totalFillLevel/totalCapacity));
						isLineTableGeneral.capacityTotal = g_i18n:formatNumber(Utils.getNoNil(totalCapacity, 0)*100);
						isLineTableGeneral.productivityColor = MultiOverlayV3:get_hl("getProzentColor", {Utils.getNoNil(totalFillLevel/totalCapacity, 0)*100, false}, "getProzentColor Productivity Storages");
						if isLineTableGeneral.productivityColor == 1 then isLineTableGeneral.productivityColor = 2;end;
						if totalCapacity > 0 then
							isLineTableGeneral.productivity = g_i18n:formatNumber(Utils.getNoNil(totalFillLevel/totalCapacity, 0)*100);
						end;
					end;
				else	
					table.insert(deleteObject, index);				
				end;
			end;
		end;
		if #deleteObject > 0 then
			for _, index in pairs (deleteObject) do				
				table.remove(moModule.storages, index);
			end;
			moModule:slotOutputCmd(true);
		end;
	end;
end;			




